part of swagger.api;



class ReportManagementApi {
  final ApiClient apiClient;

  ReportManagementApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// Get reports depends on brand name 
  ///
  /// 
  Future<ReportRes> apiBrandReportGET(String brandName, { String startDate, String endDate, String fields }) async {
    Object postBody = null;

    // verify required params are set
    if(brandName == null) {
     throw new ApiException(400, "Missing required param: brandName");
    }

    // create path and map variables
    String path = "/api/1/brands/{brandName}/reports".replaceAll("{format}","json").replaceAll("{" + "brandName" + "}", brandName.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if(startDate != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "startDate", startDate));
    }
    if(endDate != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "endDate", endDate));
    }
    if(fields != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "fields", fields));
    }
    
    List<String> contentTypes = ["application/json"];

    String contentType = contentTypes.length > 0 ? contentTypes[0] : "application/json";
    List<String> authNames = ["Token"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = new MultipartRequest(null, null);
      
      if(hasFields)
        postBody = mp;
    }
    else {
          }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);

    if(response.statusCode >= 400) {
      throw new ApiException(response.statusCode, response.body);
    } else if(response.body != null) {
      return 
          apiClient.deserialize(response.body, 'ReportRes') as ReportRes ;
    } else {
      return null;
    }
  }
  /// Get reports depends on brand name and periodical type 
  ///
  /// 
  Future<ReportRes> apiBrandTypeReportGET(String brandName, String typeEnum, { String startDate, String endDate, String fields }) async {
    Object postBody = null;

    // verify required params are set
    if(brandName == null) {
     throw new ApiException(400, "Missing required param: brandName");
    }
    if(typeEnum == null) {
     throw new ApiException(400, "Missing required param: typeEnum");
    }

    // create path and map variables
    String path = "/api/1/brands/{brandName}/types/{typeEnum}/reports".replaceAll("{format}","json").replaceAll("{" + "brandName" + "}", brandName.toString()).replaceAll("{" + "typeEnum" + "}", typeEnum.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if(startDate != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "startDate", startDate));
    }
    if(endDate != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "endDate", endDate));
    }
    if(fields != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "fields", fields));
    }
    
    List<String> contentTypes = ["application/json"];

    String contentType = contentTypes.length > 0 ? contentTypes[0] : "application/json";
    List<String> authNames = ["Token"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = new MultipartRequest(null, null);
      
      if(hasFields)
        postBody = mp;
    }
    else {
          }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);

    if(response.statusCode >= 400) {
      throw new ApiException(response.statusCode, response.body);
    } else if(response.body != null) {
      return 
          apiClient.deserialize(response.body, 'ReportRes') as ReportRes ;
    } else {
      return null;
    }
  }
  /// Get reports 
  ///
  /// 
  Future<ReportRes> apiReportGET({ String startDate, String endDate, String fields }) async {
    Object postBody = null;

    // verify required params are set

    // create path and map variables
    String path = "/api/1/reports".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if(startDate != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "startDate", startDate));
    }
    if(endDate != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "endDate", endDate));
    }
    if(fields != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "fields", fields));
    }
    
    List<String> contentTypes = ["application/json"];

    String contentType = contentTypes.length > 0 ? contentTypes[0] : "application/json";
    List<String> authNames = ["Token"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = new MultipartRequest(null, null);
      
      if(hasFields)
        postBody = mp;
    }
    else {
          }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);

    if(response.statusCode >= 400) {
      throw new ApiException(response.statusCode, response.body);
    } else if(response.body != null) {
      return 
          apiClient.deserialize(response.body, 'ReportRes') as ReportRes ;
    } else {
      return null;
    }
  }
  /// Get support fields of report 
  ///
  /// 
  Future<ReportSupportFieldsRes> apiReportSupportFieldsGET() async {
    Object postBody = null;

    // verify required params are set

    // create path and map variables
    String path = "/api/1/reports/supportFields".replaceAll("{format}","json");

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    
    List<String> contentTypes = ["application/json"];

    String contentType = contentTypes.length > 0 ? contentTypes[0] : "application/json";
    List<String> authNames = ["Token"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = new MultipartRequest(null, null);
      
      if(hasFields)
        postBody = mp;
    }
    else {
          }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);

    if(response.statusCode >= 400) {
      throw new ApiException(response.statusCode, response.body);
    } else if(response.body != null) {
      return 
          apiClient.deserialize(response.body, 'ReportSupportFieldsRes') as ReportSupportFieldsRes ;
    } else {
      return null;
    }
  }
}
