part of swagger.api;



class StreamingManagementApi {
  final ApiClient apiClient;

  StreamingManagementApi([ApiClient apiClient]) : apiClient = apiClient ?? defaultApiClient;

  /// Request live view streaming from camera device 
  ///
  /// 
  Future<StreamingUrlRes> apiLiveViewGET(String controllerId, String devId) async {
    Object postBody = null;

    // verify required params are set
    if(controllerId == null) {
     throw new ApiException(400, "Missing required param: controllerId");
    }
    if(devId == null) {
     throw new ApiException(400, "Missing required param: devId");
    }

    // create path and map variables
    String path = "/api/1/controllers/{controllerId}/devices/{devId}/live/".replaceAll("{format}","json").replaceAll("{" + "controllerId" + "}", controllerId.toString()).replaceAll("{" + "devId" + "}", devId.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    
    List<String> contentTypes = ["application/json"];

    String contentType = contentTypes.length > 0 ? contentTypes[0] : "application/json";
    List<String> authNames = ["Token"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = new MultipartRequest(null, null);
      
      if(hasFields)
        postBody = mp;
    }
    else {
          }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);

    if(response.statusCode >= 400) {
      throw new ApiException(response.statusCode, response.body);
    } else if(response.body != null) {
      return 
          apiClient.deserialize(response.body, 'StreamingUrlRes') as StreamingUrlRes ;
    } else {
      return null;
    }
  }
  /// Request playlist of recording from camera device 
  ///
  /// 
  Future<StreamingUrlRes> apiPlaylistGET(String controllerId, String devId, num startTime, num endTime) async {
    Object postBody = null;

    // verify required params are set
    if(controllerId == null) {
     throw new ApiException(400, "Missing required param: controllerId");
    }
    if(devId == null) {
     throw new ApiException(400, "Missing required param: devId");
    }
    if(startTime == null) {
     throw new ApiException(400, "Missing required param: startTime");
    }
    if(endTime == null) {
     throw new ApiException(400, "Missing required param: endTime");
    }

    // create path and map variables
    String path = "/api/1/controllers/{controllerId}/devices/{devId}/playlist/".replaceAll("{format}","json").replaceAll("{" + "controllerId" + "}", controllerId.toString()).replaceAll("{" + "devId" + "}", devId.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
      queryParams.addAll(_convertParametersForCollectionFormat("", "startTime", startTime));
      queryParams.addAll(_convertParametersForCollectionFormat("", "endTime", endTime));
    
    List<String> contentTypes = ["application/json"];

    String contentType = contentTypes.length > 0 ? contentTypes[0] : "application/json";
    List<String> authNames = ["Token"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = new MultipartRequest(null, null);
      
      if(hasFields)
        postBody = mp;
    }
    else {
          }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);

    if(response.statusCode >= 400) {
      throw new ApiException(response.statusCode, response.body);
    } else if(response.body != null) {
      return 
          apiClient.deserialize(response.body, 'StreamingUrlRes') as StreamingUrlRes ;
    } else {
      return null;
    }
  }
  /// Request latest snapshot from camera device 
  ///
  /// 
  Future<GetSnapshotRes> apiSnapshotGET(String controllerId, String devId) async {
    Object postBody = null;

    // verify required params are set
    if(controllerId == null) {
     throw new ApiException(400, "Missing required param: controllerId");
    }
    if(devId == null) {
     throw new ApiException(400, "Missing required param: devId");
    }

    // create path and map variables
    String path = "/api/1/controllers/{controllerId}/devices/{devId}/snapshot/".replaceAll("{format}","json").replaceAll("{" + "controllerId" + "}", controllerId.toString()).replaceAll("{" + "devId" + "}", devId.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    
    List<String> contentTypes = ["application/json"];

    String contentType = contentTypes.length > 0 ? contentTypes[0] : "application/json";
    List<String> authNames = ["Token"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = new MultipartRequest(null, null);
      
      if(hasFields)
        postBody = mp;
    }
    else {
          }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);

    if(response.statusCode >= 400) {
      throw new ApiException(response.statusCode, response.body);
    } else if(response.body != null) {
      return 
          apiClient.deserialize(response.body, 'GetSnapshotRes') as GetSnapshotRes ;
    } else {
      return null;
    }
  }
  /// Upload latest snapshot of camera device 
  ///
  /// 
  Future<StreamingUrlRes> apiSnapshotPOST(String controllerId, String devId, MultipartFile file, { num width, num height }) async {
    Object postBody = null;

    // verify required params are set
    if(controllerId == null) {
     throw new ApiException(400, "Missing required param: controllerId");
    }
    if(devId == null) {
     throw new ApiException(400, "Missing required param: devId");
    }
    if(file == null) {
     throw new ApiException(400, "Missing required param: file");
    }

    // create path and map variables
    String path = "/api/1/controllers/{controllerId}/devices/{devId}/snapshot/".replaceAll("{format}","json").replaceAll("{" + "controllerId" + "}", controllerId.toString()).replaceAll("{" + "devId" + "}", devId.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
    if(width != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "width", width));
    }
    if(height != null) {
      queryParams.addAll(_convertParametersForCollectionFormat("", "height", height));
    }
    
    List<String> contentTypes = ["multipart/form-data"];

    String contentType = contentTypes.length > 0 ? contentTypes[0] : "application/json";
    List<String> authNames = ["Token"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = new MultipartRequest(null, null);
      
      if (file != null) {
        hasFields = true;
        mp.fields['file'] = file.field;
        mp.files.add(file);
      }
      
      if(hasFields)
        postBody = mp;
    }
    else {
      
    }

    var response = await apiClient.invokeAPI(path,
                                             'POST',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);

    if(response.statusCode >= 400) {
      throw new ApiException(response.statusCode, response.body);
    } else if(response.body != null) {
      return 
          apiClient.deserialize(response.body, 'StreamingUrlRes') as StreamingUrlRes ;
    } else {
      return null;
    }
  }
  /// Retrive streaming records of camera in use 
  ///
  /// 
  Future<GetStreamingRecordsRes> apiStreamingRecordsGET(String controllerId, String devId, String channel) async {
    Object postBody = null;

    // verify required params are set
    if(controllerId == null) {
     throw new ApiException(400, "Missing required param: controllerId");
    }
    if(devId == null) {
     throw new ApiException(400, "Missing required param: devId");
    }
    if(channel == null) {
     throw new ApiException(400, "Missing required param: channel");
    }

    // create path and map variables
    String path = "/api/1/controllers/{controllerId}/devices/{devId}/records/".replaceAll("{format}","json").replaceAll("{" + "controllerId" + "}", controllerId.toString()).replaceAll("{" + "devId" + "}", devId.toString());

    // query params
    List<QueryParam> queryParams = [];
    Map<String, String> headerParams = {};
    Map<String, String> formParams = {};
      queryParams.addAll(_convertParametersForCollectionFormat("", "channel", channel));
    
    List<String> contentTypes = ["application/json"];

    String contentType = contentTypes.length > 0 ? contentTypes[0] : "application/json";
    List<String> authNames = ["Token"];

    if(contentType.startsWith("multipart/form-data")) {
      bool hasFields = false;
      MultipartRequest mp = new MultipartRequest(null, null);
      
      if(hasFields)
        postBody = mp;
    }
    else {
          }

    var response = await apiClient.invokeAPI(path,
                                             'GET',
                                             queryParams,
                                             postBody,
                                             headerParams,
                                             formParams,
                                             contentType,
                                             authNames);

    if(response.statusCode >= 400) {
      throw new ApiException(response.statusCode, response.body);
    } else if(response.body != null) {
      return 
          apiClient.deserialize(response.body, 'GetStreamingRecordsRes') as GetStreamingRecordsRes ;
    } else {
      return null;
    }
  }
}
